/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal.editor;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IPersistableElement;
import org.fortiss.tooling.kernel.interfaces.IHandler;
import org.fortiss.tooling.kernel.services.IModelElementService;

/**
 * {@link IEditorInput} used when opening a {@link BindingEditor}.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @levd.rating RED Rev:
 */
public final class ModelElementEditorInput implements IEditorInput {

	/** The editor input {@link EObject}. */
	private final EObject modelElement;

	/** Stores the model element handler. */
	private final IHandler<EObject> handler;

	/** Constructor. */
	public ModelElementEditorInput(EObject modelElement) {
		this.modelElement = modelElement;
		this.handler = IModelElementService.INSTANCE
				.getModelElementHandler(modelElement);
	}

	/** Returns the editor input {@link EObject}. */
	public EObject getEditorInput() {
		return modelElement;
	}

	/** Returns the model element handler. */
	public IHandler<EObject> getModelElementHandler() {
		return handler;
	}

	/** {@inheritDoc} */
	@Override
	public boolean equals(Object obj) {
		return obj instanceof ModelElementEditorInput
				&& ((ModelElementEditorInput) obj).getEditorInput().equals(
						modelElement);
	}

	/** {@inheritDoc} */
	@SuppressWarnings("rawtypes")
	@Override
	public Object getAdapter(Class adapter) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public boolean exists() {
		return modelElement.eContainer() != null;
	}

	/** {@inheritDoc} */
	@Override
	public ImageDescriptor getImageDescriptor() {
		// TODO (FH): add image support
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getName() {
		return handler.getName(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public IPersistableElement getPersistable() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getToolTipText() {
		return handler.getDescription(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public int hashCode() {
		return super.hashCode();
	}
}
